# Changelog

- This file provides a full account of all changes to `dbt-redshift`
- The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie)
- Changes are listed under the (pre-)release in which they first appear
- Subsequent releases include changes from previous releases
- "Breaking changes" listed under a version may require action from end users or external maintainers when upgrading to that version
- Do not edit this file directly. This file is auto-generated using [changie](https://github.com/miniscruff/changie)
- For details on how to document a change, see the [contributing guide](/CONTRIBUTING.md#changelog-entry)

## dbt-redshift 1.9.5 - May 13, 2025

### Features

- Add 'serverless_work_group' and 'serverless_acct_id' params to profile and connection calls ([#919](https://github.com/dbt-labs/dbt-adapters/issues/919))

### Fixes

- fix retry_all exception handling ([#1069](https://github.com/dbt-labs/dbt-adapters/issues/1069))

### Under the Hood

- allow users to declare redshift_connector debug logging via env var ([#1062](https://github.com/dbt-labs/dbt-adapters/issues/1062))

### Contributors
- [@csquire](https://github.com/csquire) ([#919](https://github.com/dbt-labs/dbt-adapters/issues/919))


## dbt-redshift 1.9.4 - April 28, 2025

### Features

- Retry `could not open relation with OID` query exceptions ([#1014](https://github.com/dbt-labs/dbt-adapters/issues/1014))
- Added `retry_all` profile config param to retry on all redshift_connector exceptions ([#1014](https://github.com/dbt-labs/dbt-adapters/issues/1014))

### Fixes

- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))

## dbt-redshift 1.9.3 - April 01, 2025

### Features

- Add IdpTokenAuthPlugin authentication method. ([#898](https://github.com/dbt-labs/dbt-adapters/issues/898))
- Make source and target tables able to be referenced via DBT_INTERNAL_DEST and DBT_INTERNAL_SOURCE for the delete/insert incremental strategy ([#910](https://github.com/dbt-labs/dbt-adapters/issues/910))

### Under the Hood

- Add retry logic for retryable exceptions ([#960](https://github.com/dbt-labs/dbt-adapters/issues/960))
- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#951](https://github.com/dbt-labs/dbt-adapters/issues/951))
- Refactor to use new batch context varaibles ([#966](https://github.com/dbt-labs/dbt-adapters/issues/966))

## dbt-redshift 1.9.2 - March 12, 2025

### Fixes

- Fix regression to re-enable browser-based IDC authentication ([#904](https://github.com/dbt-labs/dbt-adapters/issues/904))

## dbt-redshift 1.9.1 - March 07, 2025

### Features

- Add 'is_serverless' param to profile and connection calls ([#819](https://github.com/dbt-labs/dbt-adapters/issues/819))

### Under the Hood

- Handle Gracefully handle null result from backend_pid check ([#821](https://github.com/dbt-labs/dbt-adapters/issues/821))

## Previous Releases
For information on prior major and minor releases, see their changelogs:
- [1.9](https://github.com/dbt-labs/dbt-redshift/blob/1.9.latest/CHANGELOG.md)
- [1.8](https://github.com/dbt-labs/dbt-redshift/blob/1.8.latest/CHANGELOG.md)
- [1.7](https://github.com/dbt-labs/dbt-redshift/blob/1.7.latest/CHANGELOG.md)
- [1.6](https://github.com/dbt-labs/dbt-redshift/blob/1.6.latest/CHANGELOG.md)
- [1.5](https://github.com/dbt-labs/dbt-redshift/blob/1.5.latest/CHANGELOG.md)
- [1.4](https://github.com/dbt-labs/dbt-redshift/blob/1.4.latest/CHANGELOG.md)
- [1.3](https://github.com/dbt-labs/dbt-redshift/blob/1.3.latest/CHANGELOG.md)
- [1.2](https://github.com/dbt-labs/dbt-redshift/blob/1.2.latest/CHANGELOG.md)
- [1.1](https://github.com/dbt-labs/dbt-redshift/blob/1.1.latest/CHANGELOG.md)
- [1.0](https://github.com/dbt-labs/dbt-redshift/blob/1.0.latest/CHANGELOG.md)
